@@ -22,6 +22,7 @@ use Favicon\Favicon;
 use OCA\News\Config\LegacyConfig;
 use OCA\News\Config\FetcherConfig;
 use OCA\News\Hooks\UserDeleteHook;
+use OCA\News\Search\FolderSearchProvider;
 
 use OCP\AppFramework\Bootstrap\IBootContext;
 use OCP\AppFramework\Bootstrap\IBootstrap;
@@ -31,9 +32,6 @@ use OCP\AppFramework\App;
 use OCP\Files\IRootFolder;
 use OCP\Files\Node;
 
-
-use OCA\News\Db\MapperFactory;
-use OCA\News\Db\ItemMapper;
 use OCA\News\Fetcher\FeedFetcher;
 use OCA\News\Fetcher\Fetcher;
 use OCP\User\Events\BeforeUserDeletedEvent;
@@ -84,17 +82,14 @@ class Application extends App implements IBootstrap
             return $fetcher;
         });
 
+        $context->registerSearchProvider(FolderSearchProvider::class);
+
         $context->registerEventListener(BeforeUserDeletedEvent::class, UserDeleteHook::class);
 
         // parameters
         $context->registerParameter('exploreDir', __DIR__ . '/../Explore/feeds');
         $context->registerParameter('configFile', 'config.ini');
 
-        // factories
-        $context->registerService(ItemMapper::class, function (ContainerInterface $c): ItemMapper {
-            return $c->get(MapperFactory::class)->build();
-        });
-
         $context->registerService(HTMLPurifier::class, function (ContainerInterface $c): HTMLPurifier {
             $directory = $c->get(ITempManager::class)->getTempBaseDir() . '/news/cache/purifier';
 
