@@ -17,9 +17,6 @@ namespace OCA\News\Controller;
 
 use \OCP\IRequest;
 use \OCP\IUserSession;
-use \OCP\IURLGenerator;
-use \OCP\Files\IRootFolder;
-use \OCP\AppFramework\Http;
 
 class UserApiController extends ApiController
 {
